import 'package:flutter/material.dart';
import 'package:get/get.dart';

class WowText extends Text {
  /// Text bình thường
  ///
  /// Mặc định 1 dòng, canh lề trái, từ trái sang phải
  const WowText(
    String data, {
    Key key,
    int maxLines = 1,
    TextStyle style,
    TextAlign textAlign = TextAlign.start,
    TextDirection textDirection = TextDirection.ltr,
    bool softWrap = true,
  }) : super(
          data,
          key: key,
          style: style,
          textAlign: textAlign,
          textDirection: textDirection,
          maxLines: maxLines,
          softWrap: softWrap,
          overflow:
              maxLines != null ? TextOverflow.ellipsis : TextOverflow.visible,
        );

  /// Text hỗn hợp
  ///
  /// Mặc định 1 dòng, canh lề trái, từ trái sang phải
  const WowText.rich(
    InlineSpan textSpan, {
    Key key,
    int maxLines = 1,
    TextStyle style,
    TextAlign textAlign = TextAlign.start,
    TextDirection textDirection = TextDirection.ltr,
    bool softWrap = true,
  }) : super.rich(
          textSpan,
          key: key,
          style: style,
          textAlign: textAlign,
          textDirection: textDirection,
          maxLines: maxLines,
          softWrap: softWrap,
          overflow:
              maxLines != null ? TextOverflow.ellipsis : TextOverflow.visible,
        );

  /// Tiêu đề
  ///
  /// Thường dùng cho AppBar
  factory WowText.title(
    String data, {
    Key key,
    int maxLines = 1,
    Color color,
    FontWeight fontWeight,
    TextAlign textAlign = TextAlign.start,
    bool softWrap = true,
  }) =>
      WowText(
        data,
        style: Get.textTheme.headline6.copyWith(
          color: color,
          fontWeight: fontWeight,
        ),
        maxLines: maxLines,
        softWrap: softWrap,
      );

  /// Nội dung mặc định, bình thường
  factory WowText.bodyText(
    String data, {
    Key key,
    int maxLines = 1,
    Color color,
    FontWeight fontWeight,
    TextDecoration decoration,
    FontStyle fontStyle,
    TextAlign textAlign = TextAlign.start,
    bool softWrap = true,
  }) =>
      WowText(
        data,
        style: Get.textTheme.bodyText2.copyWith(
          color: color,
          fontWeight: fontWeight,
          decoration: decoration,
          fontStyle: fontStyle,
        ),
        maxLines: maxLines,
        softWrap: softWrap,
      );

  /// Nội dung chú thích, nhạt hơn mặc định
  factory WowText.caption(
    String data, {
    Key key,
    int maxLines = 1,
    Color color,
    FontWeight fontWeight,
    TextDecoration decoration,
    FontStyle fontStyle,
    TextAlign textAlign = TextAlign.start,
    bool softWrap = true,
  }) =>
      WowText(
        data,
        style: Get.textTheme.caption.copyWith(
          color: color,
          fontWeight: fontWeight,
          decoration: decoration,
          fontStyle: fontStyle,
        ),
        maxLines: maxLines,
        softWrap: softWrap,
      );

  /// Tiêu đề đầu mục
  ///
  /// Thường dùng cho các đầu mục, tiêu đề danh sách, ...
  factory WowText.listTitle(
    String data, {
    Key key,
    int maxLines = 1,
    Color color,
    FontWeight fontWeight,
    TextDecoration decoration,
    FontStyle fontStyle,
    TextAlign textAlign = TextAlign.start,
    bool softWrap = true,
  }) =>
      WowText(
        data,
        style: Get.textTheme.subtitle2.copyWith(
          color: color,
          fontWeight: fontWeight,
          decoration: decoration,
          fontStyle: fontStyle,
        ),
        maxLines: maxLines,
        softWrap: softWrap,
      );

  /// Nội dung trong các thành phần danh sách
  ///
  /// Hoặc dùng cho nội dung to hơn bình thường
  factory WowText.listItem(
    String data, {
    Key key,
    int maxLines = 1,
    Color color,
    FontWeight fontWeight,
    TextDecoration decoration,
    FontStyle fontStyle,
    TextAlign textAlign = TextAlign.start,
    bool softWrap = true,
  }) =>
      WowText(
        data,
        style: Get.textTheme.bodyText1.copyWith(
          color: color,
          fontWeight: fontWeight,
          decoration: decoration,
          fontStyle: fontStyle,
        ),
        maxLines: maxLines,
        softWrap: softWrap,
      );

  /// Nội dung trong các nút
  factory WowText.button(
    String data, {
    Key key,
    int maxLines = 1,
    Color color,
    FontWeight fontWeight,
    TextDecoration decoration,
    FontStyle fontStyle,
    TextAlign textAlign = TextAlign.start,
    bool softWrap = true,
  }) =>
      WowText(
        data,
        style: Get.textTheme.button.copyWith(
          color: color,
          fontWeight: fontWeight,
          decoration: decoration,
          fontStyle: fontStyle,
        ),
        maxLines: maxLines,
        softWrap: softWrap,
      );
}
